@@ -64,6 +64,8 @@ MainWindow::MainWindow(QWidget *parent) : KXmlGuiWindow(parent)
     m_mainWidget->widgetsHide();
     createGUI();
     actionCollection()->action("help_whats_this");
+
+    doNew();
 }
 
 MainWindow::~MainWindow()
@@ -124,7 +126,7 @@ void MainWindow::doSaveAs()
 
 void MainWindow::doNew()
 {
-	if(!askToSave())
+	if(m_model && !askToSave())
 		return;
     m_file.clear();
     delete m_model;
@@ -134,7 +136,6 @@ void MainWindow::doNew()
     m_mainWidget->clearUi(m_tmpDir->path());
     m_mainWidget->widgetsHide();
     m_fileSaved = true;
-
 }
 
 void MainWindow::doSave()
@@ -181,7 +182,7 @@ void MainWindow::doSave()
 
     compress(m_file);
     m_fileSaved = true;
-
+    setCaption(m_mainWidget->title(), !m_fileSaved);
 }
 
 
@@ -194,6 +195,7 @@ void MainWindow::openfile(const QString& filename)
     m_mainWidget->setUi(m_pt);
     m_mainWidget->widgetsHide();
     m_fileSaved = true;
+    setCaption(m_mainWidget->title(), !m_fileSaved);
 
 }
 
@@ -257,3 +259,9 @@ void MainWindow::newTmpDir(const QString &path)
     m_tmpDir->mkpath(m_tmpDir->path());
 
 }
+
+void MainWindow::doChange()
+{
+    m_fileSaved = false;
+    setCaption(m_mainWidget->title(), !m_fileSaved);
+}
